@@ -5,7 +5,7 @@ import re
 import sys
 import time
 
-from mock import patch as mockpatch
+from unittest.mock import patch as mockpatch
 
 __version__ = '0.1.4.dev0'
 
